#---------------------------------------------------------------------------#
#          Copyright (c) 1997-2010 PDFlib GmbH. All rights reserved.        #
#---------------------------------------------------------------------------#
#    This software may not be copied or distributed except as expressly     #
#    authorized by PDFlib GmbH's general license agreement or a custom      #
#    license agreement signed by PDFlib GmbH.                               #
#    For more information about licensing please refer to www.pdflib.com.   #
#---------------------------------------------------------------------------#

# $Id: pCOS.pm,v 1.7 2013/08/02 13:37:58 rjs Exp $
#
#---------------------------------------------------------------------------*
#              PDFlib - A library for generating PDF on the fly             |
#---------------------------------------------------------------------------+

package PDFlib::pCOS;

use strict;
use Carp;

use pcoslib_pl 4.0;
our $VERSION = 4.0;

sub new {
    my $class = shift;
    my $self = {};
    my $pcos = pCOS_new();

    bless $self, $class;
    $self->{pcos} = $pcos;
    pCOS_set_option($pcos, "objorient=true");

    return $self;
}

sub DESTROY {
    my $self = shift;

    pCOS_delete($self->{pcos});
}

# Automatically generated methods


sub close_document {
    my $self = shift;
    eval {
	pCOS_close_document($self->{pcos}, @_);
    };
    if ($@) {
	croak($@);
    }
}

sub convert_to_unicode {
    my $self = shift;
    my $ret;
    eval {
	$ret = pCOS_convert_to_unicode($self->{pcos}, @_);
    };
    if ($@) {
	croak($@);
    }
    return($ret);
}

sub create_pvf {
    my $self = shift;
    eval {
	pCOS_create_pvf($self->{pcos}, @_);
    };
    if ($@) {
	croak($@);
    }
}

sub delete_pvf {
    my $self = shift;
    my $ret;
    eval {
	$ret = pCOS_delete_pvf($self->{pcos}, @_);
    };
    if ($@) {
	croak($@);
    }
    return($ret);
}

sub get_apiname {
    my $self = shift;
    my $ret;
    eval {
	$ret = pCOS_get_apiname($self->{pcos}, @_);
    };
    if ($@) {
	croak($@);
    }
    return($ret);
}

sub get_errmsg {
    my $self = shift;
    my $ret;
    eval {
	$ret = pCOS_get_errmsg($self->{pcos}, @_);
    };
    if ($@) {
	croak($@);
    }
    return($ret);
}

sub get_errnum {
    my $self = shift;
    my $ret;
    eval {
	$ret = pCOS_get_errnum($self->{pcos}, @_);
    };
    if ($@) {
	croak($@);
    }
    return($ret);
}

sub info_pvf {
    my $self = shift;
    my $ret;
    eval {
	$ret = pCOS_info_pvf($self->{pcos}, @_);
    };
    if ($@) {
	croak($@);
    }
    return($ret);
}

sub open_document {
    my $self = shift;
    my $ret;
    eval {
	$ret = pCOS_open_document($self->{pcos}, @_);
    };
    if ($@) {
	croak($@);
    }
    return($ret);
}

sub open_document_mem {
    my $self = shift;
    my $ret;
    eval {
	$ret = pCOS_open_document_mem($self->{pcos}, @_);
    };
    if ($@) {
	croak($@);
    }
    return($ret);
}

sub pcos_get_number {
    my $self = shift;
    my $ret;
    eval {
	$ret = pCOS_pcos_get_number($self->{pcos}, @_);
    };
    if ($@) {
	croak($@);
    }
    return($ret);
}

sub get_number {
    my $self = shift;
    my $ret;
    eval {
	$ret = pCOS_get_number($self->{pcos}, @_);
    };
    if ($@) {
	croak($@);
    }
    return($ret);
}

sub pcos_get_string {
    my $self = shift;
    my $ret;
    eval {
	$ret = pCOS_pcos_get_string($self->{pcos}, @_);
    };
    if ($@) {
	croak($@);
    }
    return($ret);
}

sub get_string {
    my $self = shift;
    my $ret;
    eval {
	$ret = pCOS_get_string($self->{pcos}, @_);
    };
    if ($@) {
	croak($@);
    }
    return($ret);
}

sub pcos_get_stream {
    my $self = shift;
    my $ret;
    eval {
	$ret = pCOS_pcos_get_stream($self->{pcos}, @_);
    };
    if ($@) {
	croak($@);
    }
    return($ret);
}

sub get_stream {
    my $self = shift;
    my $ret;
    eval {
	$ret = pCOS_get_stream($self->{pcos}, @_);
    };
    if ($@) {
	croak($@);
    }
    return($ret);
}

sub set_option {
    my $self = shift;
    eval {
	pCOS_set_option($self->{pcos}, @_);
    };
    if ($@) {
	croak($@);
    }
}

sub utf8_to_utf16 {
    my $self = shift;
    my $ret;
    eval {
	$ret = pCOS_utf8_to_utf16($self->{pcos}, @_);
    };
    if ($@) {
	croak($@);
    }
    return($ret);
}

sub utf8_to_utf32 {
    my $self = shift;
    my $ret;
    eval {
	$ret = pCOS_utf8_to_utf32($self->{pcos}, @_);
    };
    if ($@) {
	croak($@);
    }
    return($ret);
}

sub utf16_to_utf8 {
    my $self = shift;
    my $ret;
    eval {
	$ret = pCOS_utf16_to_utf8($self->{pcos}, @_);
    };
    if ($@) {
	croak($@);
    }
    return($ret);
}

sub utf16_to_utf32 {
    my $self = shift;
    my $ret;
    eval {
	$ret = pCOS_utf16_to_utf32($self->{pcos}, @_);
    };
    if ($@) {
	croak($@);
    }
    return($ret);
}

sub utf32_to_utf8 {
    my $self = shift;
    my $ret;
    eval {
	$ret = pCOS_utf32_to_utf8($self->{pcos}, @_);
    };
    if ($@) {
	croak($@);
    }
    return($ret);
}

sub utf32_to_utf16 {
    my $self = shift;
    my $ret;
    eval {
	$ret = pCOS_utf32_to_utf16($self->{pcos}, @_);
    };
    if ($@) {
	croak($@);
    }
    return($ret);
}
